<template>
    <a-table style="width: 92%;margin-left:25px" ref="table" bordered size="middle" rowKey="id" :columns="columns"
        :rowClassName="tableRowClass" :dataSource="dataSource" :pagination="ipagination" :loading="loading">
        <!--字符串超长截取省略号显示-->
        <span slot="num" slot-scope="text" style="font-weight: bold">
            <j-ellipsis :value="text" :length="15" />
        </span>
        <span slot="name" slot-scope="text" style="font-weight: bold">
            <j-ellipsis :value="text" :length="15" />
        </span>
        <span slot="model" slot-scope="text">
            <j-ellipsis :value="text" :length="15" />
        </span>
    </a-table>
</template>

<script>

import JDictSelectTag from '@/components/dict/JDictSelectTag'
import { requestPut, getAction } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from "@/components/jeecg/JEllipsis";
import Tooltip from 'ant-design-vue/es/tooltip'
export default {
    name: 'PrecisionParametersRight',
    mixins: [JeecgListMixin],
    components: {
        Tooltip,
        JDictSelectTag,
        JInput,
        JEllipsis,
    },
    props: {
        recordSelect: {},
    },
    data() {
        return {
            equipmentId:'',
            selectedRowKeys:[],
            selectionRows:[],
            equipmentAccountId: '',
            disabled: true,
            nodeSelected: {},
            columns: [
                {
                    title: '精度参数编码',
                    dataIndex: 'precisionParametersNum',
                    align: "center",
                    ellipsis: true
                },
                {
                    title: '精度参数名称',
                    dataIndex: 'precisionParametersName',
                    align: "center",
                    ellipsis: true
                },
                {
                    title: '计量单位',
                    dataIndex: 'precisionParametersUnitName',
                    align: "center",
                    ellipsis: true
                },
                {
                  title: '初始测定值',
                  dataIndex: 'actualValue1',
                  align: "center",
                  width: 120
                },
                {
                  title: '容许范围',
                  dataIndex: 'precisionParametersUnitName1',
                  align: "center",
                },
                {
                  title: '实际测定值',
                  dataIndex: 'actualValue',
                  align: "center",
                  width: 120,
                  scopedSlots: { customRender: 'actualValue' }
                },
                {
                  title: '备注',
                    dataIndex: 'remark',
                  align: "center",
                  width: 60,
                  ellipsis: true
                },


            ],
            queryParam: {},
            ipagination: {
                current: 1,
                pageSize: 3,
                pageSizeOptions: ['3', '10', '20'],
                showTotal: (total, range) => {
                    return range[0] + '-' + range[1] + ' 共' + total + '条'
                },
                showQuickJumper: true,
                showSizeChanger: true,
                total: 0
            },
            url: {
                list: '/eam/equipmentPrecisionParameters/list',
                delete: "/eam/precisionParameters/delete",
                deleteBatch: "/eam/precisionParameters/deleteBatch",
                exportXlsUrl: "/eam/precisionParameters/exportXls",
                importExcelUrl: "eam/precisionParameters/importExcel",
            },
        }
    },
    methods: {
        onSelectChange(selectedRowKeys, selectionRows) {
        this.selectedRowKeys = selectedRowKeys;
        this.selectionRows = selectionRows;

      },
        loadData(arg) {
            if (!this.url.list) {
                this.$message.error("请设置url.list属性!")
                return
            }
            if (arg === 1) {
                this.ipagination.current = 1;
            }
            var params = this.getQueryParams();//查询条件
            if (this.equipmentId == '') {
                params.equipmentId = '-1';
            } else {
                params.equipmentId = this.equipmentId
            }
            this.loading = true;
            getAction(this.url.list, params).then((res) => {
                if (res.success) {
                    this.dataSource = res.result.records || res.result;
                    if (res.result.total) {
                        this.ipagination.total = res.result.total;
                    } else {
                        this.ipagination.total = 0;
                    }
                } else {
                    this.$message.warning(res.message)
                }
            }).finally(() => {
                this.loading = false
            })
        },
        //禁用状态样式
        tableRowClass(record, index) {
            if (record.status != "1") {
                return "frozenRowClass";
            }
            return "";
        },
        searchReset() {
            if ('-1' != this.nodeSelected.key) {
                this.disabled = false;
                this.queryParam = [];
                this.queryParam.precisionParametersCategoryId = this.nodeSelected.key;
            } else {
                this.disabled = true;
                this.queryParam = [];
            }
            this.loadData(1);
        },
    },
    watch: {
        recordSelect(val) {
            this.nodeSelected = val;
            this.precisionParametersCategoryNumName = this.nodeSelected.rfield1 + "/" + this.nodeSelected.rfield2;
            if ('-1' != this.nodeSelected.key) {
                this.disabled = false;
                this.queryParam = [];
                this.queryParam.precisionParametersCategoryId = this.nodeSelected.key;
            } else {
                this.disabled = true;
                this.queryParam = [];
            }
            this.loadData(1);
        }
    },

}
</script>

<style lang="less" scoped>
@import '~@assets/less/common.less';

/deep/ .frozenRowClass {
    color: #c9c9c9;
}

/deep/ .success {
    color: green;
}

/deep/ .error {
    color: red;
}

/deep/ .notShow {
    display: none;
}

.fontweight {
    font-weight: bold;
}
</style>